@@ -1,8 +1,8 @@
 /*
 **  OSSP sa - Socket Abstraction
-**  Copyright (c) 2001-2002 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 2001-2002 The OSSP Project <http://www.ossp.org/>
-**  Copyright (c) 2001-2002 Cable & Wireless Deutschland <http://www.cw.com/de/>
+**  Copyright (c) 2001-2004 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2001-2004 The OSSP Project <http://www.ossp.org/>
+**  Copyright (c) 2001-2004 Cable & Wireless <http://www.cw.com/>
 **
 **  This file is part of OSSP sa, a socket abstraction library which
 **  can be found at http://www.ossp.org/pkg/lib/sa/.
@@ -31,18 +31,19 @@
 #ifndef __SA_H__
 #define __SA_H__
 
-#define SA_PREFIX l2_util_
-
 /* system definitions of "size_t", "socklen_t", "struct sockaddr *" */
 #include <string.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 
 /* include optional Autoconf header */
+#define SA_PREFIX l2_util_
+#define HAVE_CONFIG_H 1
 #include "l2_config.h"
 
+
 /* fallback for POSIX socklen_t */
-#if !defined(HAVE_SOCKLEN_T)
+#if defined(HAVE_CONFIG_H) && !defined(HAVE_SOCKLEN_T)
 typedef int socklen_t;
 #endif
 
@@ -89,6 +90,8 @@ typedef int socklen_t;
 #define sa_flush        SA_CONCAT(SA_PREFIX,sa_flush)
 #define sa_recv         SA_CONCAT(SA_PREFIX,sa_recv)
 #define sa_send         SA_CONCAT(SA_PREFIX,sa_send)
+#define sa_sendf        SA_CONCAT(SA_PREFIX,sa_sendf)
+#define sa_id           SA_CONCAT(SA_PREFIX,sa_id)
 #define sa_error        SA_CONCAT(SA_PREFIX,sa_error)
 #endif
 
@@ -116,6 +119,8 @@ typedef enum {
     SA_ERR_EOF, /* End Of Communication         */
     SA_ERR_TMT, /* Communication Timeout        */
     SA_ERR_SYS, /* Operating System Error       */
+    SA_ERR_NET, /* Networking Error             */
+    SA_ERR_FMT, /* Formatting Error             */
     SA_ERR_IMP, /* Implementation Not Available */
     SA_ERR_INT  /* Internal Error               */
 } sa_rc_t;
@@ -178,7 +183,7 @@ extern sa_rc_t sa_type         (sa_t  *__sa, sa_type_t    __id);
 extern sa_rc_t sa_timeout      (sa_t  *__sa, sa_timeout_t __id, long __sec, long __usec);
 extern sa_rc_t sa_buffer       (sa_t  *__sa, sa_buffer_t  __id, size_t __size);
 extern sa_rc_t sa_option       (sa_t  *__sa, sa_option_t  __id, ...);
-extern sa_rc_t sa_syscall      (sa_t  *__sa, sa_syscall_t __id, void (*__fptr)(), void *__fctx);
+extern sa_rc_t sa_syscall      (sa_t  *__sa, sa_syscall_t __id, void (*__fptr)(void), void *__fctx);
 
 /* socket connection operations */
 extern sa_rc_t sa_bind         (sa_t  *__sa, sa_addr_t  *__laddr);
